@@ -1,4 +1,4 @@
-/* GDM - The Gnome Display Manager
+/* GDM - The GNOME Display Manager
  * Copyright (C) 1998, 1999, 2000 Martin K. Petersen <mkp@mkp.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -27,7 +27,7 @@ void     gdm_slave_start       (GdmDisplay *d);
 void     gdm_slave_greeter_ctl_no_ret (char cmd, const char *str);
 char    *gdm_slave_greeter_ctl (char cmd, const char *str);
 gboolean gdm_slave_greeter_check_interruption (void);
-gboolean gdm_slave_should_complain (void);
+gboolean gdm_slave_action_pending (void);
 
 void	 gdm_slave_send		(const char *str, gboolean wait_for_ack);
 void	 gdm_slave_send_num	(const char *opcode, long num);
@@ -37,6 +37,7 @@ gboolean gdm_slave_final_cleanup (void);
 void     gdm_slave_whack_temp_auth_file (void);
 
 gboolean gdm_slave_check_user_wants_to_log_in (const char *user);
+gboolean gdm_is_session_magic (const char *session_name);
 
 /* This is the slave child handler so that we can chain to it from elsewhere */
 void	 gdm_slave_child_handler (int sig);
