@@ -35,6 +35,7 @@
 #include <glade/glade.h>
 
 #include "gdm.h"
+#include "gdmcomm.h"
 #include "gdmcommon.h"
 #include "gdmconfig.h"
 #include "ve-miscui.h"
@@ -263,9 +264,9 @@ browse_button_cb (GtkWidget *widget, gpointer data)
 						      facedir, NULL);
 	} else {
 		gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (file_dialog),
-						     EXPANDED_DATADIR "/pixmaps");
+						     DATADIR "/pixmaps");
 		gtk_file_chooser_add_shortcut_folder (GTK_FILE_CHOOSER (file_dialog),
-						      EXPANDED_DATADIR "/pixmaps", NULL);
+						      DATADIR "/pixmaps", NULL);
 	}
 
 	filter = gtk_file_filter_new ();
@@ -306,12 +307,16 @@ main (int argc, char *argv[])
 	gtk_init(&argc, &argv);
 	photofile = g_build_filename (g_get_home_dir (), ".face", NULL);
 
+	/* Read config data in bulk */
+	gdmcomm_comm_bulk_start ();
 	face_browser = gdm_config_get_bool (GDM_KEY_BROWSER);
 	max_size     = gdm_config_get_int (GDM_KEY_USER_MAX_FILE);
 	max_width    = gdm_config_get_int (GDM_KEY_MAX_ICON_WIDTH);
 	max_height   = gdm_config_get_int (GDM_KEY_MAX_ICON_HEIGHT);
 	greeter      = gdm_config_get_string (GDM_KEY_GREETER);
 	facedir      = gdm_config_get_string (GDM_KEY_GLOBAL_FACE_DIR);
+	/* At this point we are done using the socket, so close it */
+	gdmcomm_comm_bulk_stop ();
 	imagename    = NULL;
 
 	gtk_window_set_default_icon_name ("stock_person");
